# pygbag_network_utils

## Overview

`pygbag_network_utils` is a Python library that provides network utilities for use with pygbag.

## Installation

To install `pygbag_network_utils`, use pip:

```sh
pip install pygbag_network_utils
```

## License

This project is licensed under the MIT License. For more information, see the LICENSE file.

## More Information

This library is based on work done in [pygbag-multiplayer-sandbox](https://github.com/thetechnicker/pygbag-multiplayer-sandbox).
